==> franchise_service-tomato.20190119.060710-49-sources.jar: com/jz/jar/franchise/wrapper/CoursePackWrapper.java <==
package com.jz.jar.franchise.wrapper;

import java.util.List;

import com.google.common.collect.Lists;
import com.jz.jooq.franchise.tables.pojos.CoursePackHo;
import com.jz.jooq.franchise.tables.pojos.CoursePackHoPrice;
import com.jz.jooq.franchise.tables.pojos.CoursePackSchool;

public class CoursePackWrapper {

	private String coursePackId;
	private String name;
	private Integer officalLesson;
	private Integer maxLeaveNum;
	private Integer days;
	private Integer enable;

	private Integer totalPrice;
	private Integer onePrice;
	private Integer maxDiscount;

	private Integer source;

	private List<CourseWrapper> courses;

	public static CoursePackWrapper ofMeta(CoursePackHo cp) {
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName());
	}

	public static CoursePackWrapper ofMeta(CoursePackSchool cp) {
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName());
	}

	public static CoursePackWrapper ofHo(CoursePackHo cp) {
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName())
				.setOfficalLesson(cp.getOfficalLesson()).setMaxLeaveNum(cp.getMaxLeaveNum()).setDays(cp.getDays())
				.setSource(1);
	}

	public static CoursePackWrapper ofSchool(CoursePackSchool cp) {
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName())
				.setOfficalLesson(cp.getOfficalLesson()).setMaxLeaveNum(cp.getMaxLeaveNum()).setDays(cp.getDays())
				.setTotalPrice(cp.getTotalPrice()).setOnePrice(cp.getOnePrice()).setMaxDiscount(cp.getMaxDiscount())
				.setEnable(cp.getEnable()).setSource(2);
	}

	public CoursePackWrapper setHoPrice(CoursePackHoPrice p) {
		return this.setTotalPrice(p.getTotalPrice()).setOnePrice(p.getOnePrice()).setMaxDiscount(p.getMaxDiscount());
	}

	public String getCoursePackId() {
		return coursePackId;
	}

	public CoursePackWrapper setCoursePackId(String coursePackId) {
		this.coursePackId = coursePackId;
		return this;
	}

	public String getName() {
		return name;
	}

	public CoursePackWrapper setName(String name) {
		this.name = name;
		return this;
	}

	public Integer getOfficalLesson() {
		return officalLesson;
	}

	public CoursePackWrapper setOfficalLesson(Integer officalLesson) {
		this.officalLesson = officalLesson;
		return this;
	}

	public Integer getDays() {
		return days;
	}

	public CoursePackWrapper setDays(Integer days) {
		this.days = days;
		return this;
	}

	public Integer getEnable() {
		return enable;
	}

	public CoursePackWrapper setEnable(Integer enable) {
		this.enable = enable;
		return this;
	}

	public Integer getTotalPrice() {
		return totalPrice;
	}

	public CoursePackWrapper setTotalPrice(Integer totalPrice) {
		this.totalPrice = totalPrice;
		return this;
	}

	public Integer getOnePrice() {
		return onePrice;
	}

	public CoursePackWrapper setOnePrice(Integer onePrice) {
		this.onePrice = onePrice;
		return this;
	}

	public Integer getMaxDiscount() {
		return maxDiscount;
	}

	public CoursePackWrapper setMaxDiscount(Integer maxDiscount) {
		this.maxDiscount = maxDiscount;
		return this;
	}

	public Integer getSource() {
		return source;
	}

	public CoursePackWrapper setSource(Integer source) {
		this.source = source;
		return this;
	}

	public List<CourseWrapper> getCourses() {
		return courses;
	}

	public CoursePackWrapper addCourse(CourseWrapper course) {
		if (this.courses == null) {
			this.courses = Lists.newArrayList();
		}
		this.courses.add(course);
		return this;
	}

	public Integer getMaxLeaveNum() {
		return maxLeaveNum;
	}

	public CoursePackWrapper setMaxLeaveNum(Integer maxLeaveNum) {
		this.maxLeaveNum = maxLeaveNum;
		return this;
	}

}

==> franchise_service-tomato.20190221.104707-118-sources.jar: com/jz/jar/franchise/wrapper/CoursePackWrapper.java <==
package com.jz.jar.franchise.wrapper;

import java.util.List;

import com.google.common.collect.Lists;
import com.jz.jooq.franchise.tables.pojos.CoursePackHo;
import com.jz.jooq.franchise.tables.pojos.CoursePackHoPrice;
import com.jz.jooq.franchise.tables.pojos.CoursePackSchool;
import com.jz.jooq.franchise.tables.records.CoursePackSchoolRecord;

public class CoursePackWrapper {

	private String coursePackId;
	private String name;
	private Integer officalLesson;
	private Integer maxLeaveNum;
	private Integer days;
	private Integer enable;

	private Integer totalPrice;
	private Integer onePrice;
	private Integer maxDiscount;

	private Integer source;

	private List<CourseWrapper> courses;

	public static CoursePackWrapper ofMeta(CoursePackHo cp) {
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName());
	}

	public static CoursePackWrapper ofMeta(CoursePackSchool cp) {
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName());
	}

	public static CoursePackWrapper ofHo(CoursePackHo cp) {
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName())
				.setOfficalLesson(cp.getOfficalLesson()).setMaxLeaveNum(cp.getMaxLeaveNum()).setDays(cp.getDays())
				.setSource(1);
	}

	public static CoursePackWrapper ofSchool(CoursePackSchool cp) {
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName())
				.setOfficalLesson(cp.getOfficalLesson()).setMaxLeaveNum(cp.getMaxLeaveNum()).setDays(cp.getDays())
				.setTotalPrice(cp.getTotalPrice()).setOnePrice(cp.getOnePrice()).setMaxDiscount(cp.getMaxDiscount())
				.setEnable(cp.getEnable()).setSource(2);
	}
	
	public static CoursePackWrapper ofUdCoursePack(CoursePackSchoolRecord cp){
		return new CoursePackWrapper().setCoursePackId(cp.getCoursePackId()).setName(cp.getName())
				.setOfficalLesson(cp.getOfficalLesson()).setMaxLeaveNum(cp.getMaxLeaveNum()).setDays(cp.getDays())
				.setTotalPrice(cp.getTotalPrice()).setOnePrice(cp.getOnePrice()).setMaxDiscount(cp.getMaxDiscount())
				.setEnable(cp.getEnable()).setSource(2);
	}

	public CoursePackWrapper setHoPrice(CoursePackHoPrice p) {
		return this.setTotalPrice(p.getTotalPrice()).setOnePrice(p.getOnePrice()).setMaxDiscount(p.getMaxDiscount());
	}

	public String getCoursePackId() {
		return coursePackId;
	}

	public CoursePackWrapper setCoursePackId(String coursePackId) {
		this.coursePackId = coursePackId;
		return this;
	}

	public String getName() {
		return name;
	}

	public CoursePackWrapper setName(String name) {
		this.name = name;
		return this;
	}

	public Integer getOfficalLesson() {
		return officalLesson;
	}

	public CoursePackWrapper setOfficalLesson(Integer officalLesson) {
		this.officalLesson = officalLesson;
		return this;
	}

	public Integer getDays() {
		return days;
	}

	public CoursePackWrapper setDays(Integer days) {
		this.days = days;
		return this;
	}

	public Integer getEnable() {
		return enable;
	}

	public CoursePackWrapper setEnable(Integer enable) {
		this.enable = enable;
		return this;
	}

	public Integer getTotalPrice() {
		return totalPrice;
	}

	public CoursePackWrapper setTotalPrice(Integer totalPrice) {
		this.totalPrice = totalPrice;
		return this;
	}

	public Integer getOnePrice() {
		return onePrice;
	}

	public CoursePackWrapper setOnePrice(Integer onePrice) {
		this.onePrice = onePrice;
		return this;
	}

	public Integer getMaxDiscount() {
		return maxDiscount;
	}

	public CoursePackWrapper setMaxDiscount(Integer maxDiscount) {
		this.maxDiscount = maxDiscount;
		return this;
	}

	public Integer getSource() {
		return source;
	}

	public CoursePackWrapper setSource(Integer source) {
		this.source = source;
		return this;
	}

	public List<CourseWrapper> getCourses() {
		return courses;
	}

	public CoursePackWrapper addCourse(CourseWrapper course) {
		if (this.courses == null) {
			this.courses = Lists.newArrayList();
		}
		this.courses.add(course);
		return this;
	}

	public Integer getMaxLeaveNum() {
		return maxLeaveNum;
	}

	public CoursePackWrapper setMaxLeaveNum(Integer maxLeaveNum) {
		this.maxLeaveNum = maxLeaveNum;
		return this;
	}

}
